@@ -33,9 +33,8 @@
  *
  * The UI definition format is JSON, the JavaScript Object Notation as
  * described by RFC 4627. #ClutterScript can load a JSON data stream,
- * parse it and build all the objects defined into it. The top-level node
- * in the JSON file can be a single object or an array of objects. Each object
- * must have an "id" and a "type" properties defining the name to be used
+ * parse it and build all the objects defined into it. Each object must
+ * have an "id" and a "type" properties defining the name to be used
  * to retrieve it from #ClutterScript with clutter_script_get_object(),
  * and the class type to be instanciated. Every other attribute will
  * be mapped to the class properties.
@@ -71,27 +70,6 @@
  * using ClutterScript it is possible to check the id by calling
  * clutter_get_script_id().
  *
- * Multiple objects can be defined using an array:
- *
- * |[<!-- language="plain" -->
- * [
- *   {
- *     "id"     : "red-button",
- *     "type"   : "ClutterRectangle",
- *     "width"  : 100,
- *     "height" : 100,
- *     "color"  : "&num;ff0000ff"
- *   },
- *   {
- *     "id"     : "white-button",
- *     "type"   : "ClutterRectangle",
- *     "width"  : 100,
- *     "height" : 100,
- *     "color"  : "&num;ffffffff"
- *   }
- * ]
- * ]|
- *
  * Packing can be represented using the "children" member, and passing an
  * array of objects or ids of objects already defined (but not packed: the
  * packing rules of Clutter still apply, and an actor cannot be packed
@@ -152,8 +130,9 @@
  * ]]></programlisting></informalexample>
  *
  * Implicitely defined #ClutterAlpha<!-- -->s and #ClutterTimeline<!-- -->s
- * can omit the `id`, as well as the `type` members, but will not be available
- * using clutter_script_get_object() (they can, however, be extracted using the
+ * can omit the <varname>id</varname> member, as well as the
+ * <varname>type</varname> member, but will not be available using
+ * clutter_script_get_object() (they can, however, be extracted using the
  * #ClutterBehaviour and #ClutterAlpha API respectively).
  *
  * Signal handlers can be defined inside a Clutter UI definition file and
@@ -222,30 +201,6 @@
  * animating to it. State changes on signal emission will not affect
  * the signal emission chain.
  *
- * ClutterScript supports translation using gettext: if a "translatable" key is
- * added to a property value, it will be passed through g_dgettext() before
- * being set on the created object. For example, to mark the #ClutterText:text
- * property as being translatable:
- *
- * |[
- * {
- *   "id" : "label",
- *   "type" : "ClutterText",
- *   "text" : { "translatable" : true, "string" : "Clutter Script" }
- * }
- * ]|
- *
- * In order for translation to work, the C runtime locale must have been set
- * using setlocale() before loading the #ClutterScript, and the translation
- * domain must have been set using textdomain(). If the strings in the script
- * are in a different translation domain from the rest of the program, use
- * clutter_script_set_translation_domain() to set the domain for the
- * #ClutterScript only.
- *
- * As well as the "translatable" key, ClutterScript supports optional "domain"
- * and "context" keys for specifying the message domain (if it is not the
- * default) and context for disambiguating it from other equal message strings.
- *
  * Clutter reserves the following names, so classes defining properties
  * through the usual GObject registration process should avoid using these
  * names to avoid collisions:
@@ -279,10 +234,12 @@
 #include <glib-object.h>
 #include <gmodule.h>
 
-#define CLUTTER_DISABLE_DEPRECATION_WARNINGS
-
 #include "clutter-actor.h"
+#include "clutter-alpha.h"
+#include "clutter-behaviour.h"
+#include "clutter-container.h"
 #include "clutter-stage.h"
+#include "clutter-state.h"
 #include "clutter-texture.h"
 
 #include "clutter-script.h"
@@ -293,25 +250,20 @@
 #include "clutter-private.h"
 #include "clutter-debug.h"
 
-#include "deprecated/clutter-alpha.h"
-#include "deprecated/clutter-behaviour.h"
-#include "deprecated/clutter-container.h"
-#include "deprecated/clutter-state.h"
-
 enum
 {
   PROP_0,
 
   PROP_FILENAME_SET,
   PROP_FILENAME,
-  PROP_TRANSLATION_DOMAIN,
 
   PROP_LAST
 };
 
 static GParamSpec *obj_props[PROP_LAST];
 
-#define CLUTTER_SCRIPT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_SCRIPT, ClutterScriptPrivate))
+#define CLUTTER_SCRIPT_GET_PRIVATE(obj) \
+        (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_SCRIPT, ClutterScriptPrivate))
 
 struct _ClutterScriptPrivate
 {
@@ -326,13 +278,11 @@ struct _ClutterScriptPrivate
 
   gchar **search_paths;
 
-  gchar *translation_domain;
-
   gchar *filename;
   guint is_filename : 1;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterScript, clutter_script, G_TYPE_OBJECT)
+G_DEFINE_TYPE (ClutterScript, clutter_script, G_TYPE_OBJECT);
 
 static GType
 clutter_script_real_get_type_from_name (ClutterScript *script,
@@ -344,7 +294,7 @@ clutter_script_real_get_type_from_name (ClutterScript *script,
   if (gtype != G_TYPE_INVALID)
     return gtype;
 
-  return _clutter_script_get_type_from_class (type_name);
+  return clutter_script_get_type_from_class (type_name);
 }
 
 void
@@ -366,7 +316,7 @@ property_info_free (gpointer data)
     }
 }
 
-static void
+void
 signal_info_free (gpointer data)
 {
   if (G_LIKELY (data))
@@ -435,31 +385,10 @@ clutter_script_finalize (GObject *gobject)
   g_strfreev (priv->search_paths);
   g_free (priv->filename);
   g_hash_table_destroy (priv->states);
-  g_free (priv->translation_domain);
 
   G_OBJECT_CLASS (clutter_script_parent_class)->finalize (gobject);
 }
 
-static void
-clutter_script_set_property (GObject      *gobject,
-                             guint         prop_id,
-                             const GValue *value,
-                             GParamSpec   *pspec)
-{
-  ClutterScript *script = CLUTTER_SCRIPT (gobject);
-
-  switch (prop_id)
-    {
-    case PROP_TRANSLATION_DOMAIN:
-      clutter_script_set_translation_domain (script, g_value_get_string (value));
-      break;
-
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
-      break;
-    }
-}
-
 static void
 clutter_script_get_property (GObject    *gobject,
                              guint       prop_id,
@@ -473,15 +402,9 @@ clutter_script_get_property (GObject    *gobject,
     case PROP_FILENAME_SET:
       g_value_set_boolean (value, script->priv->is_filename);
       break;
-
     case PROP_FILENAME:
       g_value_set_string (value, script->priv->filename);
       break;
-
-    case PROP_TRANSLATION_DOMAIN:
-      g_value_set_string (value, script->priv->translation_domain);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -493,6 +416,8 @@ clutter_script_class_init (ClutterScriptClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterScriptPrivate));
+
   klass->get_type_from_name = clutter_script_real_get_type_from_name;
 
   /**
@@ -526,25 +451,6 @@ clutter_script_class_init (ClutterScriptClass *klass)
                          NULL,
                          CLUTTER_PARAM_READABLE);
 
-  /**
-   * ClutterScript:translation-domain:
-   *
-   * The translation domain, used to localize strings marked as translatable
-   * inside a UI definition.
-   *
-   * If #ClutterScript:translation-domain is set to %NULL, #ClutterScript
-   * will use gettext(), otherwise g_dgettext() will be used.
-   *
-   * Since: 1.10
-   */
-  obj_props[PROP_TRANSLATION_DOMAIN] =
-    g_param_spec_string ("translation-domain",
-                         P_("Translation Domain"),
-                         P_("The translation domain used to localize string"),
-                         NULL,
-                         CLUTTER_PARAM_READWRITE);
-
-  gobject_class->set_property = clutter_script_set_property;
   gobject_class->get_property = clutter_script_get_property;
   gobject_class->finalize = clutter_script_finalize;
 
@@ -558,7 +464,7 @@ clutter_script_init (ClutterScript *script)
 {
   ClutterScriptPrivate *priv;
 
-  script->priv = priv = clutter_script_get_instance_private (script);
+  script->priv = priv = CLUTTER_SCRIPT_GET_PRIVATE (script);
 
   priv->parser = g_object_new (CLUTTER_TYPE_SCRIPT_PARSER, NULL);
   priv->parser->script = script;
@@ -694,45 +600,6 @@ clutter_script_load_from_data (ClutterScript  *script,
   return priv->last_merge_id;
 }
 
-/**
- * clutter_script_load_from_resource:
- * @script: a #ClutterScript
- * @resource_path: the resource path of the file to parse
- * @error: return location for a #GError, or %NULL
- *
- * Loads the definitions from a resource file into @script and merges with
- * the currently loaded ones, if any.
- *
- * Return value: on error, zero is returned and @error is set
- *   accordingly. On success, the merge id for the UI definitions is
- *   returned. You can use the merge id with clutter_script_unmerge_objects().
- *
- * Since: 1.10
- */
-guint
-clutter_script_load_from_resource (ClutterScript  *script,
-                                   const gchar    *resource_path,
-                                   GError        **error)
-{
-  GBytes *data;
-  guint res;
-
-  g_return_val_if_fail (CLUTTER_IS_SCRIPT (script), 0);
-
-  data = g_resources_lookup_data (resource_path, 0, error);
-  if (data == NULL)
-    return 0;
-
-  res = clutter_script_load_from_data (script,
-                                       g_bytes_get_data (data, NULL),
-                                       g_bytes_get_size (data),
-                                       error);
-
-  g_bytes_unref (data);
-
-  return res;
-}
-
 /**
  * clutter_script_get_object:
  * @script: a #ClutterScript
@@ -801,15 +668,15 @@ clutter_script_get_objects_valist (ClutterScript *script,
  * names/return location pairs should be listed, with a %NULL pointer
  * ending the list, like:
  *
- * |[
+ * <informalexample><programlisting>
  *   GObject *my_label, *a_button, *main_timeline;
  *
  *   clutter_script_get_objects (script,
- *                               "my-label", &my_label,
- *                               "a-button", &a_button,
- *                               "main-timeline", &main_timeline,
+ *                               "my-label", &amp;my_label,
+ *                               "a-button", &amp;a_button,
+ *                               "main-timeline", &amp;main_timeline,
  *                               NULL);
- * ]|
+ * </programlisting></informalexample>
  *
  * Note: This function does not increment the reference count of the
  * returned objects.
@@ -1261,9 +1128,9 @@ connect_each_object (gpointer key,
 }
 
 /**
- * clutter_script_connect_signals_full:
+ * clutter_script_connect_signals_full: (skip)
  * @script: a #ClutterScript
- * @func: (scope call): signal connection function
+ * @func: signal connection function
  * @user_data: data to be passed to the signal handlers, or %NULL
  *
  * Connects all the signals defined into a UI definition file to their
@@ -1305,8 +1172,7 @@ clutter_script_error_quark (void)
 /**
  * clutter_script_add_search_paths:
  * @script: a #ClutterScript
- * @paths: (array length=n_paths): an array of strings containing
- *   different search paths
+ * @paths: an array of strings containing different search paths
  * @n_paths: the length of the passed array
  *
  * Adds @paths to the list of search paths held by @script.
@@ -1442,7 +1308,7 @@ clutter_script_lookup_filename (ClutterScript *script,
  *   #ClutterScript instance. Use g_list_free() on the returned list when
  *   done.
  *
- * Since: 0.8
+ * Since: 0.8.2
  */
 GList *
 clutter_script_list_objects (ClutterScript *script)
@@ -1488,8 +1354,6 @@ clutter_script_list_objects (ClutterScript *script)
  * passed to this function.
  *
  * Since: 1.8
- *
- * Deprecated: 1.12
  */
 void
 clutter_script_add_states (ClutterScript *script,
@@ -1522,8 +1386,6 @@ clutter_script_add_states (ClutterScript *script,
  *   and it should not be unreferenced
  *
  * Since: 1.8
- *
- * Deprecated: 1.12
  */
 ClutterState *
 clutter_script_get_states (ClutterScript *script,
@@ -1537,50 +1399,6 @@ clutter_script_get_states (ClutterScript *script,
   return g_hash_table_lookup (script->priv->states, name);
 }
 
-/**
- * clutter_script_set_translation_domain:
- * @script: a #ClutterScript
- * @domain: (allow-none): the translation domain, or %NULL
- *
- * Sets the translation domain for @script.
- *
- * Since: 1.10
- */
-void
-clutter_script_set_translation_domain (ClutterScript *script,
-                                       const gchar   *domain)
-{
-  g_return_if_fail (CLUTTER_IS_SCRIPT (script));
-
-  if (g_strcmp0 (domain, script->priv->translation_domain) == 0)
-    return;
-
-  g_free (script->priv->translation_domain);
-  script->priv->translation_domain = g_strdup (domain);
-
-  g_object_notify_by_pspec (G_OBJECT (script), obj_props[PROP_TRANSLATION_DOMAIN]);
-}
-
-/**
- * clutter_script_get_translation_domain:
- * @script: a #ClutterScript
- *
- * Retrieves the translation domain set using
- * clutter_script_set_translation_domain().
- *
- * Return value: (transfer none): the translation domain, if any is set,
- *   or %NULL
- *
- * Since: 1.10
- */
-const gchar *
-clutter_script_get_translation_domain (ClutterScript *script)
-{
-  g_return_val_if_fail (CLUTTER_IS_SCRIPT (script), NULL);
-
-  return script->priv->translation_domain;
-}
-
 /*
  * _clutter_script_generate_fake_id:
  * @script: a #ClutterScript
